![duality-header](https://raw.githubusercontent.com/dkundih/duality/main/.logistics/duality.jpg)

![Downloads](https://img.shields.io/pypi/dm/duality?color=179&&label=Downloads&style=flat-square)
[![License](https://img.shields.io/pypi/l/duality?color=178&label=License&style=flat-square)](https://github.com/dkundih/duality/blob/main/LICENSE.txt)
[![PyPi version](https://img.shields.io/pypi/v/duality?color=178&&label=PyPi%20version&style=flat-square)](https://pypi.org/package/duality)
[![Python version](https://img.shields.io/pypi/pyversions/duality?color=178&label=Python%20version&style=flat-square)](https://pypi.org/package/duality)
[![Latest change](https://img.shields.io/github/last-commit/dkundih/duality?color=178&label=Latest%20change&style=flat-square)](https://github.com/dkundih/duality)
[![Format](https://img.shields.io/pypi/format/duality?color=178&label=Format&style=flat-square)](https://pypi.org/package/duality)

duality
=====

Data science, Data manipulation and Machine learning package.
Use permitted according to the terms of use and conditions set by the attached license.

**Example of use**

Visit https://github.com/dkundih/dualityDemonstrationRepo in order to see the demonstration of use in practical examples.

**Installation**

```sh
# using pip
pip install duality
```

**Import**

```sh
# for Python environment
import duality
```

**For whom is duality made for?**

duality is a Python package for Data science and Machine learning, designed to aid researchers and engineers to meet their goals with small effort.

**Why duality?**

duality disrupts the monotone world of data and gives it meaning.

**Is duality free to use?**

duality is completely free of charge for both personal and commercial use, but only under the conditions stated in the license. Developing such a complex module isn't easy and takes a lot of time and knowledge in several fields of science such as statistics, programming and domain knowledge, so any donation at https://patreon.com/dkundih or https://www.buymeacoffee.com/dkundih in order to keep duality free is more than welcome.

**Who stands behind duality?**

The module itself, it's maintenance, updates and stability, logo, videos, promotional materials and everything associated with duality are done by **David Kundih** from **Croatia**.

**See also:**

**David Kundih GitHub**
https://github.com/dkundih

**David Kundih PyPi**
https://pypi.org/user/dkundih

**David Kundih ResearchGate**
https://www.researchgate.net/profile/David-Kundih
